<?php
namespace Getresponse\WordPress;

defined( 'ABSPATH' ) || exit;

/**
 * Class ShopService
 * @package Getresponse\WordPress
 */
class ShopService {

	const CACHE_KEY = 'gr_shops';
	const CACHE_TIME = 300;

	/** @var Api */
	private $api;

	/**
	 * @param Api $api
	 */
	public function __construct( $api ) {
		$this->api = $api;
	}

	/**
	 * @return array
	 * @throws ApiException
	 */
	public function get_shops() {

		$shops = gr_cache_get( self::CACHE_KEY );

		if ( false === $shops ) {

			$shops = $this->api->get_shops();

			if ( empty( $shops ) ) {
				return array();
			}

			gr_cache_set( self::CACHE_KEY, $shops, self::CACHE_TIME );

		}

		return $shops;
	}

	/**
	 * @param string $shop_id
	 *
	 * @throws ApiException
	 */
	public function delete_shop( $shop_id ) {
		$this->api->delete_shop( $shop_id );
		gr_cache_delete( self::CACHE_KEY );
	}

	/**
	 * @param string $shop_name
	 * @param string $locale
	 * @param string $currency
	 *
	 * @throws ApiException
	 */
	public function add_shop( $shop_name, $locale, $currency ) {
		$this->api->add_shop( $shop_name, $locale, $currency );
		gr_cache_delete( self::CACHE_KEY );
	}
}
