<?php

use Getresponse\WordPress\ApiException;
use Getresponse\WordPress\ApiFactory;
use Getresponse\WordPress\ShopService;

defined( 'ABSPATH' ) || exit;

add_action( 'gr_settings_run', 'gr_delete_shop' );
add_action( 'gr_settings_run', 'create_new_store' );

function gr_delete_shop() {

	if ( 'remove-shop' !== gr_get( 'action' ) ) {
		return;
	}

	$shop_id = gr_get( 'id' );

	if ( empty( $shop_id ) ) {
		gr()->add_error_message( 'We couldn’t delete this store. Please check if you’ve made any changes to the store ID' );

		return;
	}

	try {
		$service = new ShopService( ApiFactory::create_api() );
		$service->delete_shop( $shop_id );
	} catch ( ApiException $e ) {
		gr()->add_error_message( 'We couldn’t delete this store. If the problem persists, please contact the GetResponse dev team.' );

		return;
	}

	gr()->add_success_message( 'Store removed' );

}

/**
 * @throws \Exception
 */
function create_new_store() {

	$submit = gr_post( 'add_shop' );

	if ( 'Submit' !== $submit ) {
		return;
	}

	$shop_name = gr_post( 'shop_name' );

	if ( strlen( $shop_name ) <= 3 ) {
		gr()->add_error_message( 'Your store name has to be at least 3 characters long' );

		return;
	}

	$language = 'EN';
	$currency = 'EUR';

	$locale = get_locale();

	if ( strlen( $locale ) > 0 ) {
		$params = explode( '_', $locale );
		$language = reset( $params );
	}

	if ( function_exists( 'get_woocommerce_currency' ) ) {
		$currency = get_woocommerce_currency();
	}

	try {
		$service = new ShopService( ApiFactory::create_api() );
		$service->add_shop(
			$shop_name,
			strtoupper( $language ),
			$currency
		);
	} catch ( ApiException $e ) {
		gr()->add_error_message( 'Looks like we didn’t expect this technical problem. If it persists, please contact the GetResponse dev team' );

		return;
	}

	gr()->add_success_message( 'GetResponse store created' );
}
